Dataset I/O Library for Review Graph Mining
===========================================

| |GPLv3|
| |Build Status|
| |wercker status|
| |Code Climate|
| |Release|

|Logo|

| This package defines dataset file format and load/output methods for
| `Review Graph Mining Project <https://rgmining.github.io/>`__.
| See `documents <https://rgmining.github.io/dataset-io/>`__ for more
  information.

Installation
------------

Use ``pip`` to install this package.

::

    pip install --upgrade rgmining-dataset-io

License
-------

| This software is released under The GNU General Public License Version
  3,
| see `COPYING <COPYING>`__ for more detail.

.. |GPLv3| image:: https://img.shields.io/badge/license-GPLv3-blue.svg
   :target: https://www.gnu.org/copyleft/gpl.html
.. |Build Status| image:: https://travis-ci.org/rgmining/dataset-io.svg?branch=master
   :target: https://travis-ci.org/rgmining/dataset-io
.. |wercker status| image:: https://app.wercker.com/status/9fee858cf80340e29b17687c0879fa4f/s/master
   :target: https://app.wercker.com/project/byKey/9fee858cf80340e29b17687c0879fa4f
.. |Code Climate| image:: https://codeclimate.com/github/rgmining/dataset-io/badges/gpa.svg
   :target: https://codeclimate.com/github/rgmining/dataset-io
.. |Release| image:: https://img.shields.io/badge/release-0.9.0-brightgreen.svg
   :target: https://github.com/rgmining/dataset-io/releases/tag/v0.9.0
.. |Logo| image:: https://rgmining.github.io/dataset-io/_static/image.png
   :target: https://rgmining.github.io/dataset-io/
